@@ -116,6 +116,8 @@ public class SamLocusIterator implements Iterable<SamLocusIterator.LocusInfo>, C
         public List<RecordAndOffset> getInsertedInRecord() {
             return (insertedInRecord == null) ? Collections.emptyList() : Collections.unmodifiableList(insertedInRecord);
         }
+        /** @return the number of records overlapping the position, with deletions included if they are being tracked. */
+        public int size() { return this.recordAndOffsets.size() + ((deletedInRecord == null) ? 0 : deletedInRecord.size()); }
 
         /**
          * @return <code>true</code> if all the RecordAndOffset lists are empty;
